==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/blocktype/groupmembers/lang/en.utf8/blocktype.groupmembers.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Liip AG, and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-groupmembers
 * @author     Liip AG
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Liip AG, http://liip.ch
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Group Members';
$string['description'] = 'Display a list of Members in this Group';
$string['show_all'] = 'View all Members of this Group…';

$string['options_numtoshow_title'] = 'Shown Members';
$string['options_numtoshow_desc'] = 'The number of members you want to display.';

$string['options_order_title'] = 'Order';
$string['options_order_desc'] = 'You can choose to display the latest group members or a random selection.';

$string['Latest'] = 'Latest';
$string['Random'] = 'Random';

$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/blocktype/groupmembers/lang/en.utf8/blocktype.groupmembers.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Liip AG, and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-groupmembers
 * @author     Liip AG
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Liip AG, http://liip.ch
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Group members';
$string['description'] = 'Display a list of members in this group';
$string['show_all'] = 'View all members of this Group…';

$string['options_numtoshow_title'] = 'Shown members';
$string['options_numtoshow_desc'] = 'The number of members you want to display.';

$string['options_order_title'] = 'Order';
$string['options_order_desc'] = 'You can choose to display the latest group members or a random selection.';

$string['Latest'] = 'Latest';
$string['Random'] = 'Random';

$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';
